/* This is "integ2.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary. */


#include "integ.h"



/* Approximates the definite integral of "integrand" between
   a low bound of "a" and a high bound of "b" using the
   rectangular method with "n" trapezoids. */

double rectangular (double a, double b, int n,
                    double integrand (double))
{

  double width,    /* The width of each rectangle */
         sum;      /* Running sum of rectangle heights */

  int i;           /* Counts through the rectangles */

  width = (b - a) / n;
  sum = 0;

  for (i = 1; i <= n; i = i+1) {
    sum = sum + integrand(a + i*width);
  }
  
  return(width * sum);

}



/* Approximates the definite integral of "integrand" between
   a low bound of "a" and a high bound of "b" using the
   trapezoidal method with "n" trapezoids. */

double trapezoidal (double a, double b, int n,
                    double integrand (double))
{

  double width,    /* The width of each trapezoid */
         sum;      /* Running sum of trapezoidal side heights */

  int i;           /* Counts though the trapezoids */

  width = (b - a) / n;
  sum = (integrand(a) + integrand(b)) / 2;

  for (i = 1; i <= n-1; i = i+1) {
    sum = sum + integrand(a+i*width);
  }

  return(width * sum);

}
