/* This is "rect4.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary. */

/* This program is an implementation and a test driver for the
   rectangular method of numerical integration. */


#include <stdio.h>
#include <math.h>



/* Returns sin(x)+2. */

double integrand (double x) {
    return(sin(x) + 2);
}



/* Approximates the definite integral of "integrand" between
   a low bound of "a" and a high bound of "b" using the
   rectangular method with "n" rectangles. */

double rectangular (double a, double b, int n)
{

  double width,    /* The width of each rectangle */
         sum;      /* Running sum of rectangle heights */

  int i;           /* Counts through the rectangles */

  width = (b - a) / n;
  sum = 0;

  for (i = 1; i <= n; i = i+1) {
    sum = sum + integrand(a + i*width);
  }
  
  return(width * sum);

}



/* Test driver for "rectangular". */

void main (void)
{

  int nrects;
  double low, high;

  printf("Enter number of rectangles to use: ");
  scanf("%d", &nrects);

  printf("Enter low bound of integration: ");
  scanf("%lf", &low);

  printf("Enter high bound of integration: ");
  scanf("%lf", &high);

  printf("%g\n", rectangular(low, high, nrects));

}
