(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5505,        201]*)
(*NotebookOutlinePosition[      6142,        224]*)
(*  CellTagsIndexPosition[      6098,        220]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "This notebook contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands from Chapter 5 of ",
  StyleBox["Introduction to Scientific Programming",
    FontSlant->"Italic"],
  " by Joseph L. Zachary."
}], "Subsection"],

Cell["\<\
(5.3)   We compute the distance to the horizon using the \
straightforwad approach.\
\>", "Text"],

Cell["Sqrt[(2.09*^7 + 66)^2 - (2.09*^7)^2]", "Input"],

Cell[TextData[{
  "(5.4)  We simulate what would happen if ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provided floating-point numbers with only four-digit mantissas.  First we \
add the radius and hill height."
}], "Text"],

Cell["2.09*^7 + 66.", "Input"],

Cell["\<\
(5.5)  Then we round the result to four digits and square it.\
\>", 
  "Text"],

Cell["(2.090*^7)^2", "Input"],

Cell["(5.6)  Next we square the radius.", "Text"],

Cell["(2.09*^7)^2", "Input"],

Cell["\<\
(5.7) We subtract the four-digit version of (5.6) from (5.5).\
\>", 
  "Text"],

Cell["4.386*^14 - 4.386*^14", "Input"],

Cell[TextData[{
  "(5.8)  Finally, we take the square root of the result from (5.7), which is \
what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " would have produced as a result if its floating-point numbers had \
four-digit mantissas."
}], "Text"],

Cell["Sqrt[0]", "Input"],

Cell["\<\
(5.11)  Now we simulate what would happen with four-digit mantissas \
using the improved method for computing the distance to the horizon.  First \
we double the radius.\
\>", "Text"],

Cell["2 * 2.09*^7", "Input"],

Cell["(5.12)  Next we multiply this result by the hill's height.", "Text"],

Cell["4.18*^7 * 66.", "Input"],

Cell["(5.13)  We square the hill's height.", "Text"],

Cell["66.^2", "Input"],

Cell["\<\
(5.14)  We add the four-digit versions of the results from (5.12) \
and (5.13).\
\>", "Text"],

Cell["2.759*^9 + 4356.", "Input"],

Cell[TextData[{
  "(5.15)  And finally we take the square root.  52530 is what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " would have produced as a result if its floating-point numbers had \
four-digit mantissas."
}], "Text"],

Cell["Sqrt[2.759*^9]", "Input"],

Cell["\<\
(5.16)  This is the distance to the horizon from a 100 foot hill.\
\
\>", "Text"],

Cell["Sqrt[2 * 2.09*^7 * 100 + 100^2]", "Input"],

Cell["\<\
(5.17)  We define a function called \"horizon\" that encapsulates \
distance to the horizon calculations.\
\>", "Text"],

Cell["horizon[R_, h_] := Sqrt[2*R*h + h^2]", "Input"],

Cell["\<\
(5.18)  We use \"horizon\" to compute the distance to the horizon \
from the top of a 100 foot hill.  The answer is the same as in (5.16).\
\>", 
  "Text"],

Cell["horizon[2.09*^7, 100]", "Input"],

Cell["\<\
(5.20)  We use \"horizon\" to compute the distance to the horizon \
from Kill Devil Hill using interval arithmetic.  This is the maximum possible \
distance ...\
\>", "Text"],

Cell["horizon[2.095*^7, 66.5]", "Input"],

Cell["(5.21)  ... and this is the minimum possible distance.", "Text"],

Cell["horizon[2.085*^7, 65.5]", "Input"],

Cell["\<\
(5.23)  We create a programmer-defined function \"horizonFast\" to \
calculate the distance to the horizon using an algebraically suspect but \
computationally acceptable approximation.\
\>", "Text"],

Cell["horizonFast[R_, h_] := Sqrt[2*R*h]", "Input"],

Cell["\<\
(5.24)  We use \"horizon\" to compute the distance to the horizon \
at high tide ...\
\>", "Text"],

Cell["horizon[2.09*^7 + 5, 66 - 5]", "Input"],

Cell["(5.25)  ... and at low tide.", "Text"],

Cell["horizon[2.09*^7 - 5, 66 + 5]", "Input"],

Cell["\<\
(5.26)  We compute the distance to the horizon from Kill Devil Hill \
when our eyepoint is three feet above the summit.\
\>", "Text"],

Cell["horizon[2.09*^7, 69]", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 19}, {Automatic, 144}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 258, 8, 62, "Subsection"],
Cell[1992, 61, 107, 3, 32, "Text"],
Cell[2102, 66, 53, 0, 27, "Input"],
Cell[2158, 68, 238, 6, 50, "Text"],
Cell[2399, 76, 30, 0, 27, "Input"],
Cell[2432, 78, 88, 3, 32, "Text"],
Cell[2523, 83, 29, 0, 27, "Input"],
Cell[2555, 85, 49, 0, 32, "Text"],
Cell[2607, 87, 28, 0, 27, "Input"],
Cell[2638, 89, 88, 3, 32, "Text"],
Cell[2729, 94, 38, 0, 27, "Input"],
Cell[2770, 96, 262, 7, 50, "Text"],
Cell[3035, 105, 24, 0, 27, "Input"],
Cell[3062, 107, 193, 4, 50, "Text"],
Cell[3258, 113, 28, 0, 27, "Input"],
Cell[3289, 115, 74, 0, 32, "Text"],
Cell[3366, 117, 30, 0, 27, "Input"],
Cell[3399, 119, 52, 0, 32, "Text"],
Cell[3454, 121, 22, 0, 27, "Input"],
Cell[3479, 123, 103, 3, 32, "Text"],
Cell[3585, 128, 33, 0, 27, "Input"],
Cell[3621, 130, 240, 6, 50, "Text"],
Cell[3864, 138, 31, 0, 27, "Input"],
Cell[3898, 140, 91, 3, 32, "Text"],
Cell[3992, 145, 48, 0, 27, "Input"],
Cell[4043, 147, 129, 3, 50, "Text"],
Cell[4175, 152, 53, 0, 27, "Input"],
Cell[4231, 154, 165, 4, 50, "Text"],
Cell[4399, 160, 38, 0, 27, "Input"],
Cell[4440, 162, 184, 4, 50, "Text"],
Cell[4627, 168, 40, 0, 27, "Input"],
Cell[4670, 170, 70, 0, 32, "Text"],
Cell[4743, 172, 40, 0, 27, "Input"],
Cell[4786, 174, 209, 4, 50, "Text"],
Cell[4998, 180, 51, 0, 27, "Input"],
Cell[5052, 182, 108, 3, 32, "Text"],
Cell[5163, 187, 45, 0, 27, "Input"],
Cell[5211, 189, 44, 0, 32, "Text"],
Cell[5258, 191, 45, 0, 27, "Input"],
Cell[5306, 193, 143, 3, 50, "Text"],
Cell[5452, 198, 37, 0, 27, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

